@@ -1,5 +1,4 @@
 require 'sync'
-require 'puppet/external/event-loop'
 require 'puppet/application'
 
 # A general class for triggering a run of another
@@ -32,7 +31,7 @@ class Puppet::Agent
       return
     end
     if disabled?
-      Puppet.notice "Skipping run of #{client_class}; administratively disabled; use 'puppet #{client_class} --enable' to re-enable."
+      Puppet.notice "Skipping run of #{client_class}; administratively disabled; use 'puppet agent --enable' to re-enable."
       return
     end
 
@@ -75,18 +74,6 @@ class Puppet::Agent
     @splayed = true
   end
 
-  # Start listening for events.  We're pretty much just listening for
-  # timer events here.
-  def start
-    # Create our timer.  Puppet will handle observing it and such.
-    timer = EventLoop::Timer.new(:interval => Puppet[:runinterval], :tolerance => 1, :start? => true) do
-      run
-    end
-
-    # Run once before we start following the timer
-    timer.sound_alarm
-  end
-
   def sync
     @sync ||= Sync.new
   end
