@@ -27,6 +27,7 @@ class Puppet::Application::Agent < Puppet::Application
       :fqdn => nil,
       :serve => [],
       :digest => :MD5,
+      :graph => true,
       :fingerprint => false,
     }.each do |opt,val|
       options[opt] = val
@@ -39,12 +40,7 @@ class Puppet::Application::Agent < Puppet::Application
   end
 
   option("--centrallogging")
-
-  option("--disable [MESSAGE]") do |message|
-    options[:disable] = true
-    options[:disable_message] = message
-  end
-
+  option("--disable")
   option("--enable")
   option("--debug","-d")
   option("--fqdn FQDN","-f")
@@ -106,7 +102,7 @@ similar), or run interactively for testing purposes.
 USAGE
 -----
 puppet agent [--certname <name>] [-D|--daemonize|--no-daemonize]
-  [-d|--debug] [--detailed-exitcodes] [--digest <digest>] [--disable [message]] [--enable]
+  [-d|--debug] [--detailed-exitcodes] [--digest <digest>] [--disable] [--enable]
   [--fingerprint] [-h|--help] [-l|--logdest syslog|<file>|console]
   [--no-client] [--noop] [-o|--onetime] [--serve <handler>] [-t|--test]
   [-v|--verbose] [-V|--version] [-w|--waitforcert <seconds>]
@@ -210,9 +206,6 @@ configuration options can also be generated by running puppet agent with
   not want the central configuration to override the local state until
   everything is tested and committed.
 
-  Disable can also take an optional message that will be reported by the
-  'puppet agent' at the next disabled run.
-
   'puppet agent' uses the same lock file while it is running, so no more
   than one 'puppet agent' process is working at a time.
 
@@ -376,25 +369,11 @@ Copyright (c) 2011 Puppet Labs, LLC Licensed under the Apache 2.0 License
     options[:detailed_exitcodes] = true
   end
 
-  # Handle the logging settings.
-  def setup_logs
-    if options[:debug] or options[:verbose]
-      Puppet::Util::Log.newdestination(:console)
-      if options[:debug]
-        Puppet::Util::Log.level = :debug
-      else
-        Puppet::Util::Log.level = :info
-      end
-    end
-
-    Puppet::Util::Log.newdestination(:syslog) unless options[:setdest]
-  end
-
   def enable_disable_client(agent)
     if options[:enable]
       agent.enable
     elsif options[:disable]
-      agent.disable(options[:disable_message] || 'reason not specified')
+      agent.disable
     end
     exit(0)
   end
