@@ -1,20 +1,19 @@
 require 'pathname'
 require 'tmpdir'
 
-module Puppet::Module::Tool
+module Puppet::ModuleTool
   module Applications
     class Unpacker < Application
 
       def initialize(filename, options = {})
         @filename = Pathname.new(filename)
-        parse_filename!
+        parsed = parse_filename(filename)
         super(options)
-        @module_dir = Pathname.new(options[:install_dir]) + @module_name
+        @module_dir = Pathname.new(options[:target_dir]) + parsed[:dir_name]
       end
 
       def run
         extract_module_to_install_dir
-        tag_revision
 
         # Return the Pathname object representing the directory where the
         # module release archive was unpacked the to, and the module release
@@ -23,23 +22,12 @@ module Puppet::Module::Tool
       end
 
       private
-
-      def tag_revision
-        File.open("#{@module_dir}/REVISION", 'w') do |f|
-          f.puts "module: #{@username}/#{@module_name}"
-          f.puts "version: #{@version}"
-          f.puts "url: file://#{@filename.expand_path}"
-          f.puts "installed: #{Time.now}"
-        end
-      end
-
       def extract_module_to_install_dir
         delete_existing_installation_or_abort!
 
         build_dir = Puppet::Forge::Cache.base_path + "tmp-unpacker-#{Digest::SHA1.hexdigest(@filename.basename.to_s)}"
         build_dir.mkpath
         begin
-          Puppet.notice "Installing #{@filename.basename} to #{@module_dir.expand_path}"
           unless system "tar xzf #{@filename} -C #{build_dir}"
             raise RuntimeError, "Could not extract contents of module archive."
           end
@@ -53,17 +41,7 @@ module Puppet::Module::Tool
 
       def delete_existing_installation_or_abort!
         return unless @module_dir.exist?
-
-        if !options[:force]
-          Puppet.warning "Existing module '#{@module_dir.expand_path}' found"
-          response = prompt "Overwrite module installed at #{@module_dir.expand_path}? [y/N]"
-          unless response =~ /y/i
-            raise RuntimeError, "Aborted installation."
-          end
-        end
-
-        Puppet.warning "Deleting #{@module_dir.expand_path}"
-        FileUtils.rm_rf @module_dir
+        FileUtils.rm_rf(@module_dir, :secure => true)
       end
     end
   end
