@@ -41,7 +41,7 @@ class Puppet::Network::HTTP::RackREST < Puppet::Network::HTTP::RackHttpHandler
     unless result.is_a?(File)
       response.write result
     else
-      response["Content-Length"] = result.stat.size
+      response["Content-Length"] = result.stat.size.to_s
       response.body = RackFile.new(result)
     end
   end
@@ -76,9 +76,7 @@ class Puppet::Network::HTTP::RackREST < Puppet::Network::HTTP::RackHttpHandler
   # request.body has some limitiations, so we need to concat it back
   # into a regular string, which is something puppet can use.
   def body(request)
-    body = ''
-    request.body.each { |part| body += part }
-    body
+    request.body.read
   end
 
   def extract_client_info(request)
