@@ -88,9 +88,7 @@ class Puppet::Node::Environment
   end
 
   def module(name)
-    mod = Puppet::Module.new(name, :environment => self)
-    return nil unless mod.exist?
-    mod
+    modules.find {|mod| mod.name == name}
   end
 
   def module_by_forge_name(forge_name)
@@ -127,8 +125,10 @@ class Puppet::Node::Environment
     modules_by_path = {}
     modulepath.each do |path|
       Dir.chdir(path) do
-        module_names = Dir.glob('*').select { |d| FileTest.directory? d }
-        modules_by_path[path] = module_names.map do |name|
+        module_names = Dir.glob('*').select do |d|
+          FileTest.directory?(d) && (File.basename(d) =~ /^[\w]+([-]{1}[\w]+)*$/)
+        end
+        modules_by_path[path] = module_names.sort.map do |name|
           Puppet::Module.new(name, :environment => self, :path => File.join(path, name))
         end
       end
