@@ -15,8 +15,8 @@ class Puppet::Node::Facts
 
   # We want to expire any cached nodes if the facts are saved.
   module NodeExpirer
-    def save(key, instance)
-      Puppet::Node.expire(instance.name)
+    def save(instance, key = nil)
+      Puppet::Node.indirection.expire(instance.name)
       super
     end
   end
@@ -35,7 +35,7 @@ class Puppet::Node::Facts
     @name = name
     @values = values
 
-    add_internal
+    add_timestamp
   end
 
   def downcase_if_necessary
@@ -59,14 +59,6 @@ class Puppet::Node::Facts
     strip_internal == other.send(:strip_internal)
   end
 
-  def timestamp=(time)
-    self.values[:_timestamp] = time
-  end
-
-  def timestamp
-    self.values[:_timestamp]
-  end
-
   def self.from_pson(data)
     result = new(data['name'], data['values'])
     result.timestamp = Time.parse(data['timestamp'])
@@ -83,13 +75,21 @@ class Puppet::Node::Facts
     }.to_pson(*args)
   end
 
-  private
-
   # Add internal data to the facts for storage.
-  def add_internal
-    self.values[:_timestamp] = Time.now
+  def add_timestamp
+    self.timestamp = Time.now
   end
 
+  def timestamp=(time)
+    self.values[:_timestamp] = time
+  end
+
+  def timestamp
+    self.values[:_timestamp]
+  end
+
+  private
+
   # Strip out that internal data.
   def strip_internal
     newvals = values.dup
