@@ -1,8 +1,8 @@
 require 'puppet/provider/package'
 
 Puppet::Type.type(:package).provide :dpkg, :parent => Puppet::Provider::Package do
-  desc "Package management via ``dpkg``.  Because this only uses ``dpkg``
-    and not ``apt``, you must specify the source of any packages you want
+  desc "Package management via `dpkg`.  Because this only uses `dpkg`
+    and not `apt`, you must specify the source of any packages you want
     to manage."
 
   has_feature :holdable
@@ -24,7 +24,7 @@ Puppet::Type.type(:package).provide :dpkg, :parent => Puppet::Provider::Package
       hash = {}
 
       # now turn each returned line into a package object
-      process.each { |line|
+      process.each_line { |line|
         if hash = parse_line(line)
           packages << new(hash)
         end
@@ -102,16 +102,15 @@ Puppet::Type.type(:package).provide :dpkg, :parent => Puppet::Provider::Package
 
     # list out our specific package
     begin
-
-            output = dpkgquery(
-        "-W", "--showformat",
-        
-        '${Status} ${Package} ${Version}\\n', @resource[:name]
+      output = dpkgquery(
+        "-W",
+        "--showformat",
+        '${Status} ${Package} ${Version}\\n',
+        @resource[:name]
       )
     rescue Puppet::ExecutionFailure
       # dpkg-query exits 1 if the package is not found.
       return {:ensure => :purged, :status => 'missing', :name => @resource[:name], :error => 'ok'}
-
     end
 
     hash = self.class.parse_line(output) || {:ensure => :absent, :status => 'missing', :name => @resource[:name], :error => 'ok'}
