@@ -3,8 +3,16 @@ require 'puppet/util/posix'
 # Manage file group ownership.
 module Puppet
   Puppet::Type.type(:file).newproperty(:group) do
-    desc "Which group should own the file.  Argument can be either group
-      name or group ID."
+    desc <<-EOT
+      Which group should own the file.  Argument can be either a group
+      name or a group ID.
+
+      On Windows, a user (such as "Administrator") can be set as a file's group
+      and a group (such as "Administrators") can be set as a file's owner;
+      however, a file's owner and group shouldn't be the same. (If the owner
+      is also the group, files with modes like `0640` will cause log churn, as
+      they will always appear out of sync.)
+    EOT
 
     validate do |group|
       raise(Puppet::Error, "Invalid group name '#{group.inspect}'") unless group and group != ""
