@@ -16,11 +16,17 @@ module Puppet
     newproperty(:ensure) do
       desc "Control what to do with this mount. Set this attribute to
         `umounted` to make sure the filesystem is in the filesystem table
-        but not mounted (if the filesystem is currently mounted, it will be unmounted).  Set it to `absent` to unmount (if necessary) and remove
+        but not mounted (if the filesystem is currently mounted, it will be
+        unmounted).  Set it to `absent` to unmount (if necessary) and remove
         the filesystem from the fstab.  Set to `mounted` to add it to the
         fstab and mount it. Set to `present` to add to fstab but not change
-        mount/unmount status"
+        mount/unmount status."
 
+      #  IS        -> SHOULD     In Sync  Action
+      #  ghost     -> present    NO       create
+      #  absent    -> present    NO       create
+      # (mounted   -> present    YES)
+      # (unmounted -> present    YES)
       newvalue(:defined) do
         provider.create
         return :mount_created
@@ -28,55 +34,66 @@ module Puppet
 
       aliasvalue :present, :defined
 
+      #  IS        -> SHOULD     In Sync  Action
+      #  ghost     -> unmounted  NO       create, unmount
+      #  absent    -> unmounted  NO       create
+      #  mounted   -> unmounted  NO       unmount
       newvalue(:unmounted) do
-        if provider.mounted?
-          syncothers
+        case self.retrieve
+        when :ghost   # (not in fstab but mounted)
+          provider.create
+          @resource.flush
           provider.unmount
           return :mount_unmounted
-        else
+        when nil, :absent  # (not in fstab and not mounted)
           provider.create
           return :mount_created
+        when :mounted # (in fstab and mounted)
+          provider.unmount
+          syncothers # I guess it's more likely that the mount was originally mounted with
+                     # the wrong attributes so I sync AFTER the umount
+          return :mount_unmounted
+        else
+          raise Puppet::Error, "Unexpected change from #{current_value} to unmounted}"
         end
       end
 
+      #  IS        -> SHOULD     In Sync  Action
+      #  ghost     -> absent     NO       unmount
+      #  mounted   -> absent     NO       provider.destroy AND unmount
+      #  unmounted -> absent     NO       provider.destroy
       newvalue(:absent, :event => :mount_deleted) do
+        current_value = self.retrieve
         provider.unmount if provider.mounted?
-
-        provider.destroy
+        provider.destroy unless current_value == :ghost
       end
 
+      #  IS        -> SHOULD     In Sync  Action
+      #  ghost     -> mounted    NO       provider.create
+      #  absent    -> mounted    NO       provider.create AND mount
+      #  unmounted -> mounted    NO       mount
       newvalue(:mounted, :event => :mount_mounted) do
         # Create the mount point if it does not already exist.
         current_value = self.retrieve
-        provider.create if current_value.nil? or current_value == :absent
+        currently_mounted = provider.mounted?
+        provider.create if [nil, :absent, :ghost].include?(current_value)
 
         syncothers
 
         # The fs can be already mounted if it was absent but mounted
-        provider.mount unless provider.mounted?
+        provider.property_hash[:needs_mount] = true unless currently_mounted
       end
 
+      # insync: mounted   -> present
+      #         unmounted -> present
       def insync?(is)
-        if should == :defined and is != :absent
+        if should == :defined and [:mounted,:unmounted].include?(is)
           true
         else
           super
         end
       end
 
-      def retrieve
-        # We need to special case :mounted; if we're absent, we still
-        # want
-        curval = super()
-        if curval == :absent
-          return :absent
-        elsif provider.mounted?
-          return :mounted
-        else
-          return :unmounted
-        end
-      end
-
       def syncothers
         # We have to flush any changes to disk.
         currentvalues = @resource.retrieve_resource
@@ -89,7 +106,7 @@ module Puppet
           if prop.name == :ensure
             false
           else
-            ! prop.insync?(currentvalues[prop])
+            ! prop.safe_insync?(currentvalues[prop])
           end
         end.each { |prop| prop.sync }.length
         @resource.flush if oos > 0
@@ -200,7 +217,7 @@ module Puppet
       newvalues(:true, :false)
       defaultto do
         case Facter.value(:operatingsystem)
-        when "FreeBSD", "Darwin"
+        when "FreeBSD", "Darwin", "AIX"
           false
         else
           true
