@@ -1,6 +1,3 @@
-#  Created by Luke Kanies on 2007-07-04.
-#  Copyright (c) 2007. All rights reserved.
-
 module Puppet::Util::LogPaths
   # return the full path to us, for logging and rollback
   # some classes (e.g., FileTypeRecords) will have to override this
@@ -15,7 +12,7 @@ module Puppet::Util::LogPaths
 
     descriptors[:tags] = tags
 
-    [:path, :file, :line, :version].each do |param|
+    [:path, :file, :line].each do |param|
       next unless value = send(param)
       descriptors[param] = value
     end
