@@ -10,7 +10,7 @@ class TerminusHelperIntegrationTester
   end
 end
 
-describe Puppet::FileServing::TerminusHelper, :fails_on_windows => true do
+describe Puppet::FileServing::TerminusHelper do
   it "should be able to recurse on a single file" do
     @path = Tempfile.new("fileset_integration")
     request = Puppet::Indirector::Request.new(:metadata, :find, @path.path, :recurse => true)
