@@ -3,7 +3,7 @@ require 'spec_helper'
 
 describe Puppet::Parser::Functions do
   before :each do
-    Puppet::Parser::Functions.rmfunction("template") if Puppet::Parser::Functions.function("template")
+    Puppet::Parser::Functions.rmfunction("template") if Puppet::Parser::Functions.functions.include?("template")
   end
 
   it "should support multiple threads autoloading the same function" do
