@@ -4,9 +4,9 @@ require 'spec_helper'
 require 'puppet/node/facts'
 require 'puppet/indirector/facts/couch'
 
-describe "Puppet::Node::Facts::Couch" do
+describe "Puppet::Node::Facts::Couch", :'fails_on_ruby_1.9.2' => true do
   describe "when couchdb is not available", :unless => Puppet.features.couchdb? do
-    it "should fail to initialize", :'fails_in_ruby_1.9.2' => true do
+    it "should fail to initialize" do
       lambda { Puppet::Node::Facts::Couch.new }.should raise_error
     end
   end
