@@ -1,6 +1,5 @@
-#!/usr/bin/env ruby
-
-require File.dirname(__FILE__) + '/../../spec_helper'
+#!/usr/bin/env rspec
+require 'spec_helper'
 require 'puppet/indirector/queue'
 
 class Puppet::Indirector::Queue::TestClient
@@ -31,10 +30,9 @@ describe Puppet::Indirector::Queue, :if => Puppet.features.pson? do
     @model = mock 'model'
     @indirection = stub 'indirection', :name => :my_queue, :register_terminus_type => nil, :model => @model
     Puppet::Indirector::Indirection.stubs(:instance).with(:my_queue).returns(@indirection)
-    @store_class = Class.new(Puppet::Indirector::Queue) do
-      def self.to_s
-        'MyQueue::MyType'
-      end
+    module MyQueue; end
+    @store_class = class MyQueue::MyType < Puppet::Indirector::Queue
+      self
     end
     @store = @store_class.new
 
@@ -42,8 +40,7 @@ describe Puppet::Indirector::Queue, :if => Puppet.features.pson? do
     @subject = @subject_class.new
     @subject.name = :me
 
-    Puppet.settings.stubs(:value).returns("bogus setting data")
-    Puppet.settings.stubs(:value).with(:queue_type).returns(:test_client)
+    Puppet[:queue_type] = :test_client
     Puppet::Util::Queue.stubs(:queue_type_to_class).with(:test_client).returns(Puppet::Indirector::Queue::TestClient)
 
     @request = stub 'request', :key => :me, :instance => @subject
@@ -112,12 +109,12 @@ describe Puppet::Indirector::Queue, :if => Puppet.features.pson? do
 
     it "should log but not propagate errors" do
       @store_class.client.expects(:subscribe).yields("foo")
-      @store_class.expects(:intern).raises ArgumentError
-      Puppet.expects(:err)
+      @store_class.expects(:intern).raises(ArgumentError)
+      expect { @store_class.subscribe {|o| o } }.should_not raise_error
 
-      @store_class.expects(:puts)
-
-      @store_class.subscribe {|o| o }
+      @logs.length.should == 1
+      @logs.first.message.should =~ /Error occured with subscription to queue my_queue for indirection my_queue: ArgumentError/
+      @logs.first.level.should == :err
     end
   end
 end
