@@ -1,6 +1,5 @@
-#!/usr/bin/env ruby
-
-require File.dirname(__FILE__) + '/../../../spec_helper'
+#!/usr/bin/env rspec
+require 'spec_helper'
 
 require 'puppet/transaction/report'
 require 'puppet/indirector/report/yaml'
@@ -23,7 +22,7 @@ describe Puppet::Transaction::Report::Yaml do
     Puppet::Transaction::Report::Yaml.name.should == :yaml
   end
 
-  it "should inconditionnally save/load from the --lastrunreport setting" do
+  it "should inconditionnally save/load from the --lastrunreport setting", :'fails_on_ruby_1.9.2' => true do
     indirection = stub 'indirection', :name => :my_yaml, :register_terminus_type => nil
     Puppet::Indirector::Indirection.stubs(:instance).with(:my_yaml).returns(indirection)
     store_class = Class.new(Puppet::Transaction::Report::Yaml) do
