@@ -1,10 +1,68 @@
-#!/usr/bin/env ruby
-
-require File.dirname(__FILE__) + '/../spec_helper'
+#!/usr/bin/env rspec
+require 'spec_helper'
 
 require 'puppet/defaults'
 require 'puppet/indirector'
 
+describe Puppet::Indirector, "when configuring routes" do
+  before :each do
+    Puppet::Node.indirection.reset_terminus_class
+    Puppet::Node.indirection.cache_class = nil
+  end
+
+  after :each do
+    Puppet::Node.indirection.reset_terminus_class
+    Puppet::Node.indirection.cache_class = nil
+  end
+
+  it "should configure routes as requested" do
+    routes = {
+      "node" => {
+        "terminus" => "exec",
+        "cache"    => "plain"
+      }
+    }
+
+    Puppet::Indirector.configure_routes(routes)
+
+    Puppet::Node.indirection.terminus_class.should == "exec"
+    Puppet::Node.indirection.cache_class.should    == "plain"
+  end
+
+  it "should fail when given an invalid indirection" do
+    routes = {
+      "fake_indirection" => {
+        "terminus" => "exec",
+        "cache"    => "plain"
+      }
+    }
+
+    expect { Puppet::Indirector.configure_routes(routes) }.should raise_error(/fake_indirection does not exist/)
+  end
+
+  it "should fail when given an invalid terminus" do
+    routes = {
+      "node" => {
+        "terminus" => "fake_terminus",
+        "cache"    => "plain"
+      }
+    }
+
+    expect { Puppet::Indirector.configure_routes(routes) }.should raise_error(/Could not find terminus fake_terminus/)
+  end
+
+  it "should fail when given an invalid cache" do
+    routes = {
+      "node" => {
+        "terminus" => "exec",
+        "cache"    => "fake_cache"
+      }
+    }
+
+    expect { Puppet::Indirector.configure_routes(routes) }.should raise_error(/Could not find terminus fake_cache/)
+  end
+end
+
 describe Puppet::Indirector, " when available to a model" do
   before do
     @thingie = Class.new do
@@ -64,24 +122,6 @@ describe Puppet::Indirector, "when registering an indirection" do
   end
 end
 
-shared_examples_for "Delegated Indirection Method" do
-  it "should delegate to the indirection" do
-    @indirection.expects(@method)
-    @thingie.send(@method, "me")
-  end
-
-  it "should pass all of the passed arguments directly to the indirection instance" do
-    @indirection.expects(@method).with("me", :one => :two)
-    @thingie.send(@method, "me", :one => :two)
-  end
-
-  it "should return the results of the delegation as its result" do
-    request = mock 'request'
-    @indirection.expects(@method).returns "yay"
-    @thingie.send(@method, "me").should == "yay"
-  end
-end
-
 describe Puppet::Indirector, "when redirecting a model" do
   before do
     @thingie = Class.new do
@@ -98,64 +138,6 @@ describe Puppet::Indirector, "when redirecting a model" do
     @thingie.ancestors.should be_include(Puppet::Indirector::Envelope)
   end
 
-  describe "when finding instances via the model" do
-    before { @method = :find }
-    it_should_behave_like "Delegated Indirection Method"
-  end
-
-  describe "when destroying instances via the model" do
-    before { @method = :destroy }
-    it_should_behave_like "Delegated Indirection Method"
-  end
-
-  describe "when searching for instances via the model" do
-    before { @method = :search }
-    it_should_behave_like "Delegated Indirection Method"
-  end
-
-  describe "when expiring instances via the model" do
-    before { @method = :expire }
-    it_should_behave_like "Delegated Indirection Method"
-  end
-
-  describe "when performing a head request" do
-    before { @method = :head }
-    it_should_behave_like "Delegated Indirection Method"
-  end
-
-  # This is an instance method, so it behaves a bit differently.
-  describe "when saving instances via the model" do
-    before do
-      @instance = @thingie.new("me")
-    end
-
-    it "should delegate to the indirection" do
-      @indirection.expects(:save)
-      @instance.save
-    end
-
-    it "should pass the instance and an optional key to the indirection's :save method" do
-      @indirection.expects(:save).with("key", @instance)
-      @instance.save "key"
-    end
-
-    it "should return the results of the delegation as its result" do
-      request = mock 'request'
-      @indirection.expects(:save).returns "yay"
-      @instance.save.should == "yay"
-    end
-  end
-
-  it "should give the model the ability to set the indirection terminus class" do
-    @indirection.expects(:terminus_class=).with(:myterm)
-    @thingie.terminus_class = :myterm
-  end
-
-  it "should give the model the ability to set the indirection cache class" do
-    @indirection.expects(:cache_class=).with(:mycache)
-    @thingie.cache_class = :mycache
-  end
-
   after do
     @indirection.delete
   end
