@@ -1,7 +1,7 @@
 require 'spec_helper'
 require 'puppet/module_tool'
 
-describe Puppet::Module::Tool::Applications::Application do
+describe Puppet::ModuleTool::Applications::Application, :fails_on_windows => true do
   describe 'app' do
 
     good_versions = %w{ 1.2.4 0.0.1 0.0.0 0.0.2-git-8-g3d316d1 0.0.3-b1 10.100.10000
@@ -14,15 +14,13 @@ describe Puppet::Module::Tool::Applications::Application do
 
     good_versions.each do |ver|
       it "should accept version string #{ver}" do
-        @app.instance_eval("@filename=%q{puppetlabs-ntp-#{ver}}")
-        @app.parse_filename!
+        @app.parse_filename("puppetlabs-ntp-#{ver}")
       end
     end
 
     bad_versions.each do |ver|
       it "should not accept version string #{ver}" do
-        @app.instance_eval("@filename=%q{puppetlabs-ntp-#{ver}}")
-        lambda { @app.parse_filename! }.should raise_error
+        lambda { @app.parse_filename("puppetlabs-ntp-#{ver}") }.should raise_error
       end
     end
   end
