@@ -25,6 +25,38 @@ describe Puppet::Network::Handler::FileServer do
     @mount = Puppet::Network::Handler::FileServer::Mount.new("some_path", @basedir)
   end
 
+  describe "when parsing the fileserver.conf" do
+    it "should create a valid mount when a valid conf is read" do
+      config_file = tmpfile('fileserver.conf')
+      mountdir = tmpdir('mountdir')
+
+      conf_text = <<-HEREDOC
+        [mymount]
+          path #{mountdir}
+          allow anyone.com
+          deny nobody.com
+      HEREDOC
+      File.open(config_file, 'w') { |f| f.write conf_text }
+
+      fs = Puppet::Network::Handler::FileServer.new(:Config => config_file) 
+      mounts = fs.instance_variable_get(:@mounts)
+      mount = mounts["mymount"]
+      mount.path == mountdir
+      mount.instance_variable_get(:@declarations).map {|d| d.pattern}.should =~ [["com", "nobody"], ["com", "anyone"]]
+    end
+
+    ['path', 'allow', 'deny'].each do |arg|
+      it "should error if config file doesn't specify a mount for #{arg} argument" do
+        config_file = tmpfile('fileserver.conf')
+        File.open(config_file, 'w') { |f| f.puts "#{arg} 127.0.0.1/24" }
+
+        expect { 
+          Puppet::Network::Handler::FileServer.new(:Config => config_file) 
+        }.should raise_error(Puppet::Network::Handler::FileServerError, "No mount specified for argument #{arg} 127.0.0.1/24")
+      end
+    end
+  end
+
   it "should list a single directory" do
     @mount.list("/", false, false).should == [["/", "directory"]]
   end
@@ -41,12 +73,12 @@ describe Puppet::Network::Handler::FileServer do
     @mount.list("/no_such_file", false, false).should be(nil)
   end
 
-  it "should list a symbolic link as a file when given the link path" do
+  it "should list a symbolic link as a file when given the link path", :unless => Puppet.features.microsoft_windows? do
     File.symlink(@file, @link)
     @mount.list("/aLink", false, false).should == [["/", "file"]]
   end
 
-  it "should return nil for a dangling symbolic link when given the link path" do
+  it "should return nil for a dangling symbolic link when given the link path", :unless => Puppet.features.microsoft_windows? do
     File.symlink("/some/where", @link)
     @mount.list("/aLink", false, false).should be(nil)
   end
@@ -106,18 +138,18 @@ describe Puppet::Network::Handler::FileServer do
     list.sort.should == [   ["/aFile", "file"], ["/", "directory"] , ["/nested_dir", "directory"], ["/nested_dir/nested_dir_file", "file"]].sort
   end
 
-  it "should list a valid symbolic link as a file when recursing base dir" do
+  it "should list a valid symbolic link as a file when recursing base dir", :unless => Puppet.features.microsoft_windows? do
     File.symlink(@file, @link)
     list = @mount.list("/", true, false)
     list.sort.should == [ ["/", "directory"], ["/aFile", "file"], ["/aLink", "file"] ].sort
   end
 
-  it "should not error when a dangling symlink is present" do
+  it "should not error when a dangling symlink is present", :unless => Puppet.features.microsoft_windows? do
     File.symlink("/some/where", @link)
     lambda { @mount.list("/", true, false) }.should_not raise_error
   end
 
-  it "should return the directory contents of valid entries when a dangling symlink is present" do
+  it "should return the directory contents of valid entries when a dangling symlink is present", :unless => Puppet.features.microsoft_windows? do
     File.symlink("/some/where", @link)
     list = @mount.list("/", true, false)
     list.sort.should == [ ["/aFile", "file"], ["/", "directory"] ].sort
