@@ -1,6 +1,5 @@
-#!/usr/bin/env ruby
-
-require File.dirname(__FILE__) + '/../../spec_helper'
+#!/usr/bin/env rspec
+require 'spec_helper'
 
 require 'puppet/network/rights'
 
@@ -17,15 +16,15 @@ describe Puppet::Network::Rights do
         rights.allow("/", "*")
         rights.restrict_method("/", allowed_method)
         rights.restrict_authenticated("/", :any)
-        request = Puppet::Indirector::Request.new(:indirection_name, :head, "key")
-        rights.is_request_forbidden_and_why?(request).should == nil
+        rights.is_request_forbidden_and_why?(:indirection_name, :head, "key", {}).should == nil
       end
     end
 
     it "should disallow the request if neither :find nor :save is allowed" do
       rights = Puppet::Network::Rights.new
-      request = Puppet::Indirector::Request.new(:indirection_name, :head, "key")
-      rights.is_request_forbidden_and_why?(request).should be_instance_of(Puppet::Network::AuthorizationError)
+      why_forbidden = rights.is_request_forbidden_and_why?(:indirection_name, :head, "key", {})
+      why_forbidden.should be_instance_of(Puppet::Network::AuthorizationError)
+      why_forbidden.to_s.should == "Forbidden request:  access to /indirection_name/key [find]"
     end
   end
 
