@@ -1,6 +1,5 @@
-#!/usr/bin/env ruby
-
-require File.dirname(__FILE__) + '/../../spec_helper'
+#!/usr/bin/env rspec
+require 'spec_helper'
 
 require 'puppet/provider/cisco'
 
@@ -13,4 +12,4 @@ describe Puppet::Provider::Cisco do
     Puppet::Util::NetworkDevice::Cisco::Device.expects(:new).returns :device
     Puppet::Provider::Cisco.device(:url).should == :device
   end
-end
\ No newline at end of file
+end
