@@ -34,7 +34,8 @@ describe Puppet::Type.type(:cron), :unless => Puppet.features.microsoft_windows?
   end
 
 
-  describe "when validating attribute" do
+  describe "when validating values" do
+
     describe "ensure" do
       it "should support present as a value for ensure" do
         proc { described_class.new(:name => 'foo', :ensure => :present) }.should_not raise_error
@@ -459,6 +460,25 @@ describe Puppet::Type.type(:cron), :unless => Puppet.features.microsoft_windows?
     end
   end
 
+  describe "when autorequiring resources" do
+
+    before :each do
+      @user_bob = Puppet::Type.type(:user).new(:name => 'bob', :ensure => :present)
+      @user_alice = Puppet::Type.type(:user).new(:name => 'alice', :ensure => :present)
+      @catalog = Puppet::Resource::Catalog.new
+      @catalog.add_resource @user_bob, @user_alice
+    end
+
+    it "should autorequire the user" do
+      @resource = described_class.new(:name => 'dummy', :command => '/usr/bin/uptime', :user => 'alice')
+      @catalog.add_resource @resource
+      req = @resource.autorequire
+      req.size.should == 1
+      req[0].target.must == @resource
+      req[0].source.must == @user_alice
+    end
+  end
+
   it "should require a command when adding an entry" do
     entry = described_class.new(:name => "test_entry", :ensure => :present)
     expect { entry.value(:command) }.should raise_error(Puppet::Error, /No command/)
