@@ -6,6 +6,7 @@ require 'puppet/util/network_device/transport/telnet'
 describe Puppet::Util::NetworkDevice::Transport::Telnet do
 
   before(:each) do
+    TCPSocket.stubs(:open).returns stub_everything('tcp')
     @transport = Puppet::Util::NetworkDevice::Transport::Telnet.new()
   end
 
@@ -13,6 +14,14 @@ describe Puppet::Util::NetworkDevice::Transport::Telnet do
     @transport.should_not be_handles_login
   end
 
+  it "should not open any files" do
+    File.expects(:open).never
+    @transport.host = "localhost"
+    @transport.port = 23
+
+    @transport.connect
+  end
+
   it "should connect to the given host and port" do
     Net::Telnet.expects(:new).with { |args| args["Host"] == "localhost" && args["Port"] == 23 }.returns stub_everything
     @transport.host = "localhost"
